/*
 * Copyright (C) 2004 ONO, Masayuki <mono101@skill-engineering.com>
 *
 * This file may be distributed and/or modified under the terms of the
 * GNU General Public License version 2 as published by the Free Software
 * Foundation and appearing in the file LICENSE.GPL included in the
 * packaging of this file.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See COPYING for GPL licensing information.
 *
 */

#include <qpe/config.h>
#include "Fish.h"
#include "FishSetting.h"

#include <qtextcodec.h>
#define _T(str) QTextCodec::codecForLocale()->toUnicode(str)

Fish::Fish()
{
	m_fishWidget = NULL;
}

Fish::~Fish()
{	
	if ( m_fishWidget )
	{
		delete m_fishWidget;
		m_fishWidget = NULL;
	}
}

QWidget* Fish::Init( int nMode )
{
	switch( nMode )
	{
	case LUS_NORMAL:
		{
			/* create the central widget */
			m_fishWidget = new FishWidget();
			readConfig();
		}
		break;
	case LUS_PREVIEW:
	default:
		{
			m_fishWidget = NULL;
		}
		break;
	}
	return m_fishWidget;
}

QString Fish::Name()
{
	return "Fish";
}

QString Fish::Version()
{
	return "1.0.0";
}

QString Fish::Comment()
{
	return "The original \"Fish\"" \
			"\nhttp://www.linux-solutions.at/projects/zaurus/games-Fish.html\n" \
			"This is a version of modified to LUSScreenSaver plug-in.";
}

bool Fish::CanCustomize()
{
	return TRUE;
}

void Fish::Setting()
{
	FishSetting dlg( NULL, "SETTINGS", TRUE, 0 );
	dlg.exec();
}

void Fish::Start()
{
	if ( m_fishWidget )
	{
		m_fishWidget->show();
	}
}

void Fish::Stop()
{
	if ( m_fishWidget )
	{
		delete m_fishWidget;
		m_fishWidget = NULL;
	}
}

void Fish::readConfig(void)
{
    Config cfg("Fish");

    cfg.setGroup("Settings");

    int bubbles = cfg.readNumEntry("Bubbles", 20);
    if (bubbles <= 0) {
	m_bubbles = 0;
    } else if (bubbles <= 10) {
	m_bubbles = 10;
    } else if (bubbles <= 20) {
	m_bubbles = 20;
    } else if (bubbles <= 30) {
	m_bubbles = 30;
    } else if (bubbles <= 40) {
	m_bubbles = 40;
    } else {
	m_bubbles = 50;
    }
    m_fishWidget->updateBubbles(m_bubbles);

    int fish = cfg.readNumEntry("Fish", 1);
    if (fish <= 0) {
	m_fish = 0;
    } else if (fish >= 10) {
	m_fish = 10;
    } else {
	m_fish = fish;
    }
    m_fishWidget->updateFish(m_fish);

    int timer = cfg.readNumEntry("Timer", 50);
    if (timer <= 50) {
	m_timer = 50;
    } else if (timer <= 100) {
	m_timer = 100;
    } else {
	m_timer = 150;
    }
    m_fishWidget->updateTimer(m_timer);
}

void Fish::writeConfig(void)
{
    Config cfg("Fish");

    cfg.setGroup("Settings");
    cfg.writeEntry("Bubbles", m_bubbles);
    cfg.writeEntry("Fish", m_fish);
    cfg.writeEntry("Timer", m_timer);
}

QRESULT Fish::queryInterface(const QUuid& uuid, QUnknownInterface** iface)
{
	*iface = 0;
	if ( uuid == IID_QUnknown || uuid == IID_LUSScreenSaver )
	{
		*iface = this;
	}

	if ( *iface )
	{
		(*iface)->addRef();
	}
	return QS_OK;
}

Q_EXPORT_INTERFACE()
{
	Q_CREATE_INSTANCE( Fish )
}

