/*
	Setting Widget for LUSScreenSaver Plugin Fish 
	Copyright (C) 2004 ONO,Masayuki.<mono101@skill-engineering.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "FishSetting.h"
#include <qpushbutton.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qwhatsthis.h>
#include <qgroupbox.h>
#include <qpe/config.h>
#include <qpe/qpeapplication.h>
#include <qradiobutton.h>
#include <qbuttongroup.h>

#include <qtextcodec.h>
#define _T(str) QTextCodec::codecForLocale()->toUnicode(str)

FishSetting::FishSetting( QWidget* parent,  const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	if ( ! name )
	{
		setName( "SettingDialog" );
	}

	setCaption( "SETTINGS" );

	BaseLayout = new QVBoxLayout( this ); 
	BaseLayout->setSpacing( 6 );
	BaseLayout->setMargin( 11 );

	DefButtonsLayout = new QHBoxLayout( this ); 
	DefButtonsLayout->setSpacing( 6 );
	DefButtonsLayout->setMargin( 11 );

	BaseGroupBox = new QGroupBox( this, "BaseGroupBox" );
	BaseGroupBox->setTitle( "" );
	BaseGroupBox->setColumnLayout( 0, Qt::Horizontal );
	BaseGroupBox->layout()->setSpacing( 0 );
	BaseGroupBox->layout()->setMargin( 0 );
	BaseGroupBoxLayout = new QHBoxLayout( BaseGroupBox->layout() );
	BaseGroupBoxLayout->setAlignment( Qt::AlignCenter );
	BaseGroupBoxLayout->setSpacing( 6 );
	BaseGroupBoxLayout->setMargin( 11 );

	FishButtonGroup = new QButtonGroup( 6, Qt::Vertical, "Fish"
												, BaseGroupBox, "FishButtonGroup" );
	FishButtonGroup->setExclusive( TRUE );
	FishRadio0 = new QRadioButton( "0", FishButtonGroup, "Fish0" );
	FishRadio1 = new QRadioButton( "1", FishButtonGroup, "Fish1" );
	FishRadio2 = new QRadioButton( "2", FishButtonGroup, "Fish2" );
	FishRadio3 = new QRadioButton( "3", FishButtonGroup, "Fish3" );
	FishRadio4 = new QRadioButton( "4", FishButtonGroup, "Fish4" );
	FishRadio5 = new QRadioButton( "5", FishButtonGroup, "Fish5" );
	FishRadio6 = new QRadioButton( "6", FishButtonGroup, "Fish6" );
	FishRadio7 = new QRadioButton( "7", FishButtonGroup, "Fish7" );
	FishRadio8 = new QRadioButton( "8", FishButtonGroup, "Fish8" );
	FishRadio9 = new QRadioButton( "9", FishButtonGroup, "Fish9" );
	FishRadio10 = new QRadioButton( "10", FishButtonGroup, "Fish10" );
	
	BubbleButtonGroup = new QButtonGroup( 6, Qt::Vertical, "Bubbles"
												, BaseGroupBox, "BubbleButtonGroup" );
	BubbleButtonGroup->setExclusive( TRUE );
	BubbleRadio0 = new QRadioButton( "0", BubbleButtonGroup, "Bubble0" );
	BubbleRadio10 = new QRadioButton( "10", BubbleButtonGroup, "Bubble10" );
	BubbleRadio20 = new QRadioButton( "20", BubbleButtonGroup, "Bubble20" );
	BubbleRadio30 = new QRadioButton( "30", BubbleButtonGroup, "Bubble30" );
	BubbleRadio40 = new QRadioButton( "40", BubbleButtonGroup, "Bubble40" );
	BubbleRadio50 = new QRadioButton( "50", BubbleButtonGroup, "Bubble50" );

	TimerButtonGroup = new QButtonGroup( 3, Qt::Vertical, "Timer"
												, BaseGroupBox, "TimerButtonGroup" );
	TimerButtonGroup->setExclusive( TRUE );
	TimerRadio50 = new QRadioButton( "50", TimerButtonGroup, "Timer50" );
	TimerRadio100 = new QRadioButton( "100", TimerButtonGroup, "Timer100" );
	TimerRadio150 = new QRadioButton( "150", TimerButtonGroup, "Timer150" );

	BaseGroupBoxLayout->addWidget( FishButtonGroup );
	BaseGroupBoxLayout->addWidget( BubbleButtonGroup );
	BaseGroupBoxLayout->addWidget( TimerButtonGroup );

	Config cfg( "Fish" );
	cfg.setGroup("Settings");
	int nFish = cfg.readNumEntry( "Fish", 1 );
	int nBubble = cfg.readNumEntry( "Bubbles", 10 );
	int nTimer = cfg.readNumEntry( "Timer", 50 );

	QRadioButton* pF = (QRadioButton*) FishButtonGroup->find( nFish );
	pF->setChecked( TRUE );

	QRadioButton* pB = (QRadioButton*) BubbleButtonGroup->find( nBubble / 10 );
	pB->setChecked( TRUE );

	QRadioButton* pT = (QRadioButton*) TimerButtonGroup->find( nTimer / 50 - 1 );
	pT->setChecked( TRUE );

	PushButton1 = new QPushButton( this, "PushButton1" );
	PushButton1->setText( _T( "Ŭ" ) );

	PushButton2 = new QPushButton( this, "PushButton2" );
	PushButton2->setText( _T( "󥻥" ) );
	
	DefButtonsLayout->addWidget( PushButton1 );
	DefButtonsLayout->addWidget( PushButton2 );

	BaseLayout->addWidget( BaseGroupBox );
	BaseLayout->addLayout( DefButtonsLayout );
	
	connect( PushButton1 ,SIGNAL( clicked() ), this, SLOT( accept() ) );
	connect( PushButton2 ,SIGNAL( clicked() ), this, SLOT( close() ) );

	showMaximized();
}

void FishSetting::accept()
{
	Config cfg( "Fish" );
	cfg.setGroup( "Settings" );

	cfg.writeEntry( "Fish", FishButtonGroup->id( FishButtonGroup->selected() ) );
	cfg.writeEntry( "Bubbles", BubbleButtonGroup->id( BubbleButtonGroup->selected() ) * 10 );
	cfg.writeEntry( "Timer", ( TimerButtonGroup->id( TimerButtonGroup->selected() ) + 1 ) * 50 );

	close();
}

void FishSetting::closeEvent( QCloseEvent* e )
{
	e->accept();
}


FishSetting::~FishSetting()
{
    // no need to delete child widgets, Qt does it all for us
}

